# Games

## 1. Goal
The Goal of this project is to implement 3 Games: Tic Tac Toe, 2048, Mine Sweeper.<br>
**Tic Tac Toe:** A 3X3 grid where we can have option to play as single player or two player. In Single player game we will play against Tic Tac Toe AI bot where the bot try to find the optimal move and will try to defeat us.<br>
**2048:** we can play a single player 2048 game and you can also see a demo like how to play the game.<br>
**Mine Sweeper:** Minesweeper is a single-player puzzle video game. The objective of the game is to clear a rectangular board containing hidden "mines" or bombs without detonating any of them, with help from clues about the number of neighbouring mines in each field.<br>


**Development in progress:**<br>
**ToDo items:**<br>
1)update readme.md file<br>
2)write documentation<br>
3)develop test case suite to test the py files<br>
